@@ -5,16 +5,15 @@ use warnings;
 
 use IO::Async::Loop;
 use IO::Async::Stream;
+use IO::Async::Listener;
 
 my $PORT = 12345;
 
 my $loop = IO::Async::Loop->new;
 
-$loop->listen(
-   service  => $PORT,
-   socktype => 'stream',
-
+my $listener = IO::Async::Listener->new(
    on_accept => sub {
+      my $self = shift;
       my ( $socket ) = @_;
 
       # $socket is just an IO::Socket reference
@@ -28,9 +27,8 @@ $loop->listen(
 
       $clientstream->write( "Your address is " . $peeraddr . "\n" );
 
-      $loop->resolve(
-         type => 'getnameinfo',
-         data => [ $socket->peername ],
+      $loop->resolver->getnameinfo(
+         addr => $socket->peername,
 
          on_resolved => sub {
             my ( $host, $service ) = @_;
@@ -43,6 +41,13 @@ $loop->listen(
          },
       );
    },
+);
+
+$loop->add( $listener );
+
+$listener->listen(
+   service  => $PORT,
+   socktype => 'stream',
 
    on_resolve_error => sub { die "Cannot resolve - $_[0]\n"; },
    on_listen_error  => sub { die "Cannot listen\n"; },
