@@ -8,7 +8,7 @@ package IO::Async::Function;
 use strict;
 use warnings;
 
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 use base qw( IO::Async::Notifier );
 use IO::Async::Timer::Countdown;
@@ -500,6 +500,12 @@ sub _init
 
    my $code = $params->{code};
    $params->{code} = sub {
+      # If -CS is in effect STDIN and STDOUT will be set to UTF-8 mode. Since
+      # we're communicating binary structures and not Unicode text we need to
+      # enable binmode
+      STDIN->binmode;
+      STDOUT->binmode;
+
       while(1) {
          my $n = _read_exactly( \*STDIN, my $lenbuffer, 4 );
          defined $n or die "Cannot read - $!";
